==> owncloud-5.0.0.tar.bz2: owncloud/apps/calendar/l10n/si_LK.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "සියලු දිනදසුන් සම්පූර්ණයෙන් හැඹිලිගත නොකල යුතුයි",
"Everything seems to be completely cached" => "දිස්වන සියල්ල සම්පූර්ණයෙන්ම හැඹිලිගත කරන්න",
"No calendars found." => "දිනදසුන් හමුවී නැත.",
"No events found." => "සිදුවීම් හමුවී නැත.",
"Wrong calendar" => "වැරදි දිනදසුනක්",
"You do not have the permissions to edit this event." => "මෙම සිදුවීම සංස්කරණය කිරීම සදහා ඔබට අවසර නොමැත.",
"The file contained either no events or all events are already saved in your calendar." => "ලිපිගොනුවේ තුල කිසිදු සිදුවීමක් නොමැත හෝ සියලු සිදුවීම් දැනටමත් ඔබගේ දිනදසුනේ සුරැකී පවතී.",
"events has been saved in the new calendar" => "නව දිනදසුනක සිදුවීම් සුරකින ලදී",
"Import failed" => "ආයත කිරීම අසාර්ථකයි",
"events has been saved in your calendar" => "ඔබේ දිනදසුනේ සිදුවීම් සුරකින ලදී",
"New Timezone:" => "නව වේලා කලාපය:",
"Timezone changed" => "වේලා කලාපය වෙනස්කරන ලදී.",
"Invalid request" => "අවලංගු අයැදුමක්",
"Calendar" => "දිනදසුන",
"Deletion failed" => "මකාදැමීම අසාර්ථකයි",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "දිදිදි දි මාමාමාමා [ වවවව]{ - [දිදිදි දි] මාමාමාමා වවවව}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "දිදිදි දි මාමාමාමා [ වවවව] පැපැ:මිමි{ - [ දිදිදි දි මාමාමාමා වවවව] පැපැ:මිමි}",
"user" => "පරිශිලකයා",
"group" => "කණ්ඩායම",
"Editable" => "සැකසිය හැක",
"Shareable" => "හවුල් කරගතහැක",
"Deletable" => "මකාදැමිය හැක",
"ddd" => "දිදිදි",
"ddd M/d" => "දිදිදි මා/දි",
"dddd M/d" => "දිදිදිදි මා/දි",
"MMMM yyyy" => "මාමාමාමා වවවව",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "මාමාමා දි[ වවවව]{ '&#8212;'[ මාමාමා] දි වවවව}",
"dddd, MMM d, yyyy" => "දිදිදිදි, මාමාමා දි, වවවව",
"Sunday" => "ඉරිදා",
"Monday" => "සඳුදා",
"Tuesday" => "අඟහරුවාදා",
"Wednesday" => "බදාදා",
"Thursday" => "බ්‍රහස්පතින්දා",
"Friday" => "සිකුරාදා",
"Saturday" => "සෙනසුරාදා",
"Sun." => "ඉරිදා",
"Mon." => "සඳුදා",
"Tue." => "අඟ.",
"Wed." => "බදාදා",
"Thu." => "බ්‍රහස්.",
"Fri." => "සිකු.",
"Sat." => "සෙන.",
"January" => "ජනවාරි",
"February" => "පෙබරවාරි",
"March" => "මාර්තු",
"April" => "අප්‍රේල්",
"May" => "මැයි",
"June" => "ජූනි",
"July" => "ජූලි",
"August" => "අගෝස්තු",
"September" => "සැප්තැම්බර්",
"October" => "ඔක්තෝබර",
"November" => "නොවැම්බර්",
"December" => "දෙසැම්බර්",
"Jan." => "ජන.",
"Feb." => "පෙබ.",
"Mar." => "මාර්තු",
"Apr." => "අප්‍රේල්",
"May." => "මැයි",
"Jun." => "ජුනි",
"Jul." => "ජුලි",
"Aug." => "අගෝ.",
"Sep." => "සැප්.",
"Oct." => "ඔක්.",
"Nov." => "නොවැ.",
"Dec." => "දෙසැ.",
"All day" => "සියලු දින",
"New Calendar" => "නව දිනදසුන",
"Title" => "මාතෘකාව",
"From Date" => "දින සිට",
"From Time" => "වේලාවේ සිට",
"To Date" => "දින දක්වා",
"To Time" => "වේලාව දක්වා",
"The event ends before it starts" => "සිදුවීම ආරම්භකිරීමට පෙර අවසන්වුනි",
"There was a database fail" => "දත්ත සමුදායේ දෝෂයක්",
"Birthday" => "උපන්දින",
"Business" => "ව්‍යාපාරික",
"Call" => "ඇමතුම",
"Clients" => "සේවාලාභින්",
"Deliverer" => "බාරදෙන්නා",
"Holidays" => "නිවාඩු දින",
"Ideas" => "අදහස්",
"Journey" => "සංචාරය",
"Jubilee" => "උත්සවය/ජුබිලිය",
"Meeting" => "රැස්වීම",
"Other" => "වෙනත්",
"Personal" => "පෞද්ගලික",
"Projects" => "ව්‍යාපෘති",
"Questions" => "ප්‍රශ්න",
"Work" => "කාර්යය",
"by" => "විසින්",
"unnamed" => "නිර්නාමික",
"You do not have the permissions to update this calendar." => "මෙම දින දසුන යාත්කාලීන කිරීම සදහා ඔබට අවසර නොමැත",
"You do not have the permissions to delete this calendar." => "මෙම දින දසුන මකාදැමිම සදහා ඔබට අවසර නොමැත",
"You do not have the permissions to add to this calendar." => "මෙම දින දසුනට එකතු කිරීම සදහා ඔබට අවසර නොමැත",
"You do not have the permissions to add events to this calendar." => "මෙම දින දසුනට සිදුවීම් එකතු කිරීම සදහා ඔබට අවසර නොමැත",
"You do not have the permissions to delete this event." => "මෙම සිදුවීම මකාදැමීම සදහා ඔබට අවසර නොමැත.",
"Busy" => "කාර්යබහුල",
"Public" => "පොදු",
"Private" => "පෞද්ගලික",
"Confidential" => "රහස්‍ය",
"Does not repeat" => "පුනරාවර්ථන නොවේ",
"Daily" => "දිනපතා",
"Weekly" => "සතිපතා",
"Every Weekday" => "සෑම වැඩකරන දිනකම",
"Bi-Weekly" => "දෙසතියකට වරක්",
"Monthly" => "මාසික",
"Yearly" => "වාර්ෂික",
"never" => "කවදාවත්",
"by occurrences" => "සිදුවීම් අනුව",
"by date" => "නව දිනදසුන",
"by monthday" => "මාසයේ දින අනුව",
"by weekday" => "සතියේ දින අනුව",
"events week of month" => "මාසයකදී සතියක තිබෙන සිදුවීම්",
"first" => "පළමු",
"second" => "දෙවන ",
"third" => "තෙවන",
"fourth" => "සිව්වන",
"fifth" => "පස්වන",
"last" => "අවසාන",
"by events date" => "සිදුවීම් දිනය අනුව",
"by yearday(s)" => "වර්ශයේ දිනයන් අනුව",
"by weeknumber(s)" => "සතියේ අංකය අනුව",
"by day and month" => "දිනය හා මාසය අනුව",
"Date" => "දිනය",
"Cal." => "දිනද.",
"Week" => "සතිය",
"Month" => "මාසය",
"List" => "ලැයිස්තුව",
"Today" => "අද",
"Settings" => "සිටුවම",
"Your calendars" => "ඔබේ දිනදසුන",
"CalDav Link" => "CalDav සබැදිය",
"Share Calendar" => "බෙදාහදාගත් දිනදසුන",
"Download" => "බාන්න",
"Edit" => "සැකසීම",
"Delete" => "මකන්න",
"New calendar" => "නව දින දර්ශනය",
"Edit calendar" => "දිනදසුන සකසන්න",
"Displayname" => "පෙන්වන නම",
"Active" => "සක්‍රීය",
"Calendar color" => "දිනදසුනේ පැහැය",
"Save" => "සුරකින්න",
"Submit" => "යොමු කරන්න",
"Cancel" => "එපා",
"Edit an event" => "සිදුවීම් සංස්කරණය",
"Export" => "නිර්යාත කරන්න",
"Eventinfo" => "සිදුවීම්විස්තරය",
"Repeating" => "පුනරාවර්ථනයන්",
"Alarm" => "සීනුව",
"Attendees" => "කැටුව යන්නන්",
"Share" => "අංශය/පංගුව",
"Title of the Event" => "සිදුවීමේ මාතෘකාව",
"Category" => "ප්‍රභේද",
"Separate categories with commas" => "ප්‍රභේදයන් කොමා වලින් වෙන්කරන්න",
"Edit categories" => "ප්‍රභේදයන් සංස්කරණය",
"All Day Event" => "දිනයේ සියලු සිදුවීම්",
"From" => "සිට",
"To" => "දකවා",
"Advanced options" => "ඉහල විකල්ප",
"Location" => "ස්ථානය",
"Location of the Event" => "සිදුවීම පිළිබද ස්ථානය",
"Description" => "විස්තර",
"Description of the Event" => "සිදුවීම පිළිබද විස්තරය",
"Repeat" => "පුනරාවර්ථන",
"Advanced" => "දියුණු/උසස්",
"Select weekdays" => "තෝරාගත් සතියේ දින",
"Select days" => "තෝරාගත් දිනයන්",
"and the events day of year." => "සහ වසරේ සිදුවීම් සිදුවු දිනය.",
"and the events day of month." => "සහ මාසයේ සිදුවීම් සිදුවු දිනය.",
"Select months" => "තෝරාගත් මාස ",
"Select weeks" => "තෝරාගත් සති",
"and the events week of year." => "සහ වසරේ සිදුවීම් සිදුවු සතිය.",
"Interval" => "විවේකය",
"End" => "අවසානය",
"occurrences" => "සිදුවීම්",
"create a new calendar" => "නව දිනදසුනක් නිර්මාණය කරන්න",
"Import a calendar file" => "දිනදසුන් ගොනුවක් ආයත කරන්න",
"Please choose a calendar" => "කරුණාකර දිනදසුනක් තෝරන්න",
"Name of new calendar" => "නව  දිනදසුනේ නම ",
"Take an available name!" => "තිබෙන නමක් ගැනීම!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "මෙම නමින් තිබෙන දිනදසුනක් දැනටම අඩංගුව පවතී. ඔබ මෙය දිගටම කරන්නේනම්, මෙම දිනදසුන ඉදිරියෙදි මුසුවේ.",
"Remove all events from the selected calendar" => "තෝරාගත් දින දර්ශකයේ සඳහන් සියලු සිදුවීම් ඉවත් කරන්න",
"Import" => "ආයාත කරන්න",
"Close Dialog" => "සංවාදය නැවැත්වීම",
"Create a new event" => "නව සිදුවීමක් නිර්මාණය කරන්න",
"Share with:" => "සමග බෙදාහදාගැනීම:",
"Shared with" => "සමග බෙදාහදාගත්",
"Unshare" => "නොබෙදු",
"Nobody" => "කවුරුවත් නෑ",
"Shared via calendar" => "දිනදසුන හරහා බෙදාහදා ගැනීම්",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "සටහන: ඉදිරියේදී සිදුවීම් වල ක්‍රියාකාරකම්  දිනදසුන හරහා බෙදාහදා ගැනීම්, සම්පූර්ණ දිනදසුන බෙදාහදා ගැනීමේදි අවධානමකට ලක්විය හැක.",
"View an event" => "සිදුවීම දක්වන්න",
"No categories selected" => "ප්‍රවර්ගයන් කිසිවක් තෝරනු ලැබුවේ නැත",
"of" => "ගේ",
"at" => "දි",
"General" => "සාමාන්‍යයෙන්",
"Timezone" => "වේලා කලාපය",
"Update timezone automatically" => "ස්වයංක්‍රීයව වේලා කලාපය යාවත්කාලීන කිරිම.",
"Time format" => "කාල හැඩතලය",
"24h" => "පැය 24",
"12h" => "පැය 12",
"Start week on" => "ආරම්භකරන සතිය",
"Cache" => "හැඹිලිය",
"Clear cache for repeating events" => "පුනරාවර්ථන සිදුවීම් සදහා හැඹිලිය හිස් කරන්න",
"URLs" => "URLs",
"Calendar CalDAV syncing addresses" => "දිනදසුන CalDAV syncing ලිපිනය",
"more info" => "වැඩිදුරටත්",
"Primary address (Kontact et al)" => "ප්‍රාථමික ලිපිනය(හැම විටම සම්බන්ධ කරගත හැක)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "iදින දසුන(න්) කියවීම සදහා පමණි "
);

==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/apps/calendar/l10n/si_LK.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "සියලු දිනදසුන් සම්පූර්ණයෙන් හැඹිලිගත නොකල යුතුයි",
"Everything seems to be completely cached" => "දිස්වන සියල්ල සම්පූර්ණයෙන්ම හැඹිලිගත කරන්න",
"No calendars found." => "දිනදසුන් හමුවී නැත.",
"No events found." => "සිදුවීම් හමුවී නැත.",
"Wrong calendar" => "වැරදි දිනදසුනක්",
"You do not have the permissions to edit this event." => "මෙම සිදුවීම සංස්කරණය කිරීම සදහා ඔබට අවසර නොමැත.",
"The file contained either no events or all events are already saved in your calendar." => "ලිපිගොනුවේ තුල කිසිදු සිදුවීමක් නොමැත හෝ සියලු සිදුවීම් දැනටමත් ඔබගේ දිනදසුනේ සුරැකී පවතී.",
"Import failed" => "ආයත කිරීම අසාර්ථකයි",
"New Timezone:" => "නව වේලා කලාපය:",
"Timezone changed" => "වේලා කලාපය වෙනස්කරන ලදී.",
"Invalid request" => "අවලංගු අයැදුමක්",
"Calendar" => "දිනදසුන",
"Deletion failed" => "මකාදැමීම අසාර්ථකයි",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "දිදිදි දි මාමාමාමා [ වවවව]{ - [දිදිදි දි] මාමාමාමා වවවව}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "දිදිදි දි මාමාමාමා [ වවවව] පැපැ:මිමි{ - [ දිදිදි දි මාමාමාමා වවවව] පැපැ:මිමි}",
"group" => "කණ්ඩායම",
"can edit" => "සංස්කරණය කළ හැක",
"ddd" => "දිදිදි",
"ddd M/d" => "දිදිදි මා/දි",
"dddd M/d" => "දිදිදිදි මා/දි",
"MMMM yyyy" => "මාමාමාමා වවවව",
"dddd, MMM d, yyyy" => "දිදිදිදි, මාමාමා දි, වවවව",
"Sunday" => "ඉරිදා",
"Monday" => "සඳුදා",
"Tuesday" => "අඟහරුවාදා",
"Wednesday" => "බදාදා",
"Thursday" => "බ්‍රහස්පතින්දා",
"Friday" => "සිකුරාදා",
"Saturday" => "සෙනසුරාදා",
"Sun." => "ඉරිදා",
"Mon." => "සඳුදා",
"Tue." => "අඟ.",
"Wed." => "බදාදා",
"Thu." => "බ්‍රහස්.",
"Fri." => "සිකු.",
"Sat." => "සෙන.",
"January" => "ජනවාරි",
"February" => "පෙබරවාරි",
"March" => "මාර්තු",
"April" => "අප්‍රේල්",
"May" => "මැයි",
"June" => "ජූනි",
"July" => "ජූලි",
"August" => "අගෝස්තු",
"September" => "සැප්තැම්බර්",
"October" => "ඔක්තෝබර",
"November" => "නොවැම්බර්",
"December" => "දෙසැම්බර්",
"Jan." => "ජන.",
"Feb." => "පෙබ.",
"Mar." => "මාර්තු",
"Apr." => "අප්‍රේල්",
"May." => "මැයි",
"Jun." => "ජුනි",
"Jul." => "ජුලි",
"Aug." => "අගෝ.",
"Sep." => "සැප්.",
"Oct." => "ඔක්.",
"Nov." => "නොවැ.",
"Dec." => "දෙසැ.",
"All day" => "සියලු දින",
"New Calendar" => "නව දිනදසුන",
"Title" => "මාතෘකාව",
"From Date" => "දින සිට",
"From Time" => "වේලාවේ සිට",
"To Date" => "දින දක්වා",
"To Time" => "වේලාව දක්වා",
"The event ends before it starts" => "සිදුවීම ආරම්භකිරීමට පෙර අවසන්වුනි",
"There was a database fail" => "දත්ත සමුදායේ දෝෂයක්",
"Birthday" => "උපන්දින",
"Business" => "ව්‍යාපාරික",
"Call" => "ඇමතුම",
"Clients" => "සේවාලාභින්",
"Deliverer" => "බාරදෙන්නා",
"Holidays" => "නිවාඩු දින",
"Ideas" => "අදහස්",
"Journey" => "සංචාරය",
"Jubilee" => "උත්සවය/ජුබිලිය",
"Meeting" => "රැස්වීම",
"Other" => "වෙනත්",
"Personal" => "පෞද්ගලික",
"Projects" => "ව්‍යාපෘති",
"Questions" => "ප්‍රශ්න",
"Work" => "කාර්යය",
"by" => "විසින්",
"unnamed" => "නිර්නාමික",
"You do not have the permissions to update this calendar." => "මෙම දින දසුන යාත්කාලීන කිරීම සදහා ඔබට අවසර නොමැත",
"You do not have the permissions to delete this calendar." => "මෙම දින දසුන මකාදැමිම සදහා ඔබට අවසර නොමැත",
"You do not have the permissions to add to this calendar." => "මෙම දින දසුනට එකතු කිරීම සදහා ඔබට අවසර නොමැත",
"You do not have the permissions to add events to this calendar." => "මෙම දින දසුනට සිදුවීම් එකතු කිරීම සදහා ඔබට අවසර නොමැත",
"You do not have the permissions to delete this event." => "මෙම සිදුවීම මකාදැමීම සදහා ඔබට අවසර නොමැත.",
"Busy" => "කාර්යබහුල",
"Does not repeat" => "පුනරාවර්ථන නොවේ",
"Daily" => "දිනපතා",
"Weekly" => "සතිපතා",
"Every Weekday" => "සෑම වැඩකරන දිනකම",
"Bi-Weekly" => "දෙසතියකට වරක්",
"Monthly" => "මාසික",
"Yearly" => "වාර්ෂික",
"never" => "කවදාවත්",
"by occurrences" => "සිදුවීම් අනුව",
"by date" => "නව දිනදසුන",
"by monthday" => "මාසයේ දින අනුව",
"by weekday" => "සතියේ දින අනුව",
"events week of month" => "මාසයකදී සතියක තිබෙන සිදුවීම්",
"first" => "පළමු",
"second" => "දෙවන ",
"third" => "තෙවන",
"fourth" => "සිව්වන",
"fifth" => "පස්වන",
"last" => "අවසාන",
"by events date" => "සිදුවීම් දිනය අනුව",
"by yearday(s)" => "වර්ශයේ දිනයන් අනුව",
"by weeknumber(s)" => "සතියේ අංකය අනුව",
"by day and month" => "දිනය හා මාසය අනුව",
"Date" => "දිනය",
"Cal." => "දිනද.",
"Week" => "සතිය",
"Month" => "මාසය",
"Today" => "අද",
"CalDav Link" => "CalDav සබැදිය",
"Timezone" => "වේලා කලාපය",
"Update timezone automatically" => "ස්වයංක්‍රීයව වේලා කලාපය යාවත්කාලීන කිරිම.",
"Time format" => "කාල හැඩතලය",
"24h" => "පැය 24",
"12h" => "පැය 12",
"Start week on" => "ආරම්භකරන සතිය",
"Cache" => "හැඹිලිය",
"Clear cache for repeating events" => "පුනරාවර්ථන සිදුවීම් සදහා හැඹිලිය හිස් කරන්න",
"Share Calendar" => "බෙදාහදාගත් දිනදසුන",
"Download" => "බාන්න",
"Edit" => "සැකසීම",
"Delete" => "මකන්න",
"New calendar" => "නව දින දර්ශනය",
"Edit calendar" => "දිනදසුන සකසන්න",
"Eventinfo" => "සිදුවීම්විස්තරය",
"Repeating" => "පුනරාවර්ථනයන්",
"Alarm" => "සීනුව",
"Attendees" => "කැටුව යන්නන්",
"Share" => "අංශය/පංගුව",
"Title of the Event" => "සිදුවීමේ මාතෘකාව",
"from" => "වෙතින්",
"All Day Event" => "දිනයේ සියලු සිදුවීම්",
"Advanced options" => "ඉහල විකල්ප",
"Location" => "ස්ථානය",
"Edit categories" => "ප්‍රභේදයන් සංස්කරණය",
"Description" => "විස්තර",
"Repeat" => "පුනරාවර්ථන",
"Advanced" => "දියුණු/උසස්",
"Select weekdays" => "තෝරාගත් සතියේ දින",
"Select days" => "තෝරාගත් දිනයන්",
"and the events day of year." => "සහ වසරේ සිදුවීම් සිදුවු දිනය.",
"and the events day of month." => "සහ මාසයේ සිදුවීම් සිදුවු දිනය.",
"Select months" => "තෝරාගත් මාස ",
"Select weeks" => "තෝරාගත් සති",
"and the events week of year." => "සහ වසරේ සිදුවීම් සිදුවු සතිය.",
"Interval" => "විවේකය",
"End" => "අවසානය",
"occurrences" => "සිදුවීම්",
"create a new calendar" => "නව දිනදසුනක් නිර්මාණය කරන්න",
"Import a calendar file" => "දිනදසුන් ගොනුවක් ආයත කරන්න",
"Please choose a calendar" => "කරුණාකර දිනදසුනක් තෝරන්න",
"Name of new calendar" => "නව  දිනදසුනේ නම ",
"Take an available name!" => "තිබෙන නමක් ගැනීම!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "මෙම නමින් තිබෙන දිනදසුනක් දැනටම අඩංගුව පවතී. ඔබ මෙය දිගටම කරන්නේනම්, මෙම දිනදසුන ඉදිරියෙදි මුසුවේ.",
"Remove all events from the selected calendar" => "තෝරාගත් දින දර්ශකයේ සඳහන් සියලු සිදුවීම් ඉවත් කරන්න",
"Import" => "ආයාත කරන්න",
"Close Dialog" => "සංවාදය නැවැත්වීම",
"Create a new event" => "නව සිදුවීමක් නිර්මාණය කරන්න",
"Unshare" => "නොබෙදු",
"Shared via calendar" => "දිනදසුන හරහා බෙදාහදා ගැනීම්",
"View an event" => "සිදුවීම දක්වන්න",
"Category" => "ප්‍රභේද",
"No categories selected" => "ප්‍රවර්ගයන් කිසිවක් තෝරනු ලැබුවේ නැත",
"From" => "සිට",
"at" => "දි",
"To" => "දකවා"
);
